@@ -26,7 +26,7 @@ def available_converters(server_url='http://localhost:6543'):
 
 
 def main():
-    print(plac.call(available_converters))
+    plac.call(available_converters)
 
 if __name__ == '__main__':
     main()
