@@ -11,7 +11,6 @@ import json
 import time
 import pprint
 import requests
-from pp.client.python.logger import getLogger
 
 @plac.annotations(
     server_url=('URL of Produce & Publish API)', 'option', 's')
@@ -19,14 +18,14 @@ from pp.client.python.logger import getLogger
 def version(server_url='http://localhost:6543'):
     if server_url.endswith('/'):
         server_url = server_url[:-1]
-    result = requests.get(server_url + '/api/version')
+    result = requests.get(server_url + '/version')
     if result.status_code == 200:
         pprint.pprint(result.json())
     else:
         print(result)
 
 def main():
-    print(plac.call(version))
+    plac.call(version)
 
 if __name__ == '__main__':
     main()
